##### Lesser Horseshoe Bat Swarming Analysis Script ####
#....####

# A GAM model of activity at Hobbit Hole in 2015 and 2016 (model  reported in TABLE 1) ####

#### Reading in and checking the data ####
dframe1 <- read.csv(file.choose())  # select "Hip Hobbit 2015 & 2016.CSV"
summary(dframe1)

# Change year into a factor with 2 levels (2015 and 2016)
dframe1$year <- as.factor(dframe1$year)
summary(dframe1)
#....####

# The model ####
library(mgcv)
model1 <- gam(no ~ year + s(week, by = year, k=8)
              # + s(tfil, k=6) + s(rfil, k=6)    # checking for non-linear effects
              + tfil + rfil,                     # linear effects of temperature and rainfall
              family=negbin(link="log", theta= 1.25),   # overdispersion parameter theta = 1.25
              data = dframe1)

# Model validation ####
over.dispersion.statistic <- model1$deviance / model1$df.residual
over.dispersion.statistic

summary(model1)
names(model1)
AIC(model1)

# Checking model assumptions
resid <- residuals(model1)
hist(resid)
fits <- fitted.values(model1)
plot(resid ~ fits, log="x")
#....####


# Plotting seasonal variation in 2015 vs. 2016 (FIGURE 2) ####

quartz()

plot(no ~ week, pch=1, col = "red",
     data = dframe1, subset = dframe1$year=="2015", 
     xlim = c(10,45),
     ylim = c(0,2000),
     las=1,
     xlab = "Week", ylab = "No. of files recorded")
points(no ~ week, pch=1, col = "blue",
       data = dframe1, subset = dframe1$year=="2016")


pdat <- expand.grid(week=seq(16,44,0.1), nighthrs=6, year = "2015", tfil=12, rfil=0)
preds <- predict(model1, newdata=pdat, se.fit=T, type="response")
predframe <- data.frame(pdat, preds)
predframe

lines(fit ~ week, data=predframe, lwd=2, col= "red")
lines(fit + se.fit ~ week, data=predframe, lty=2, col= "red")
lines(fit - se.fit ~ week, data=predframe, lty=2, col= "red")


pdat <- expand.grid(week=seq(12,41,0.1), nighthrs=6, year = "2016", tfil=12, rfil=0)
preds <- predict(model1, newdata=pdat, se.fit=T, type="response")
predframe <- data.frame(pdat, preds)
predframe

lines(fit ~ week, data=predframe, lwd=2, col= "blue")
lines(fit + se.fit ~ week, data=predframe, lty=2, col= "blue")
lines(fit - se.fit ~ week, data=predframe, lty=2, col= "blue")
#....####
#....####

#### A GAM model of Hobbit vs. woodland vs. other caves in 2016 (model reported in TABLE 2) ####

#### Reading in and checking the data ####
dframe1 <- read.csv(file.choose())  # select "Hip 2016 multiple locations.CSV"
summary(dframe1)

dframe1$loc <- as.factor(dframe1$loc) # Turn Locating into a factor
#....####

# The model ####

library(mgcv)
model1 <- gam(no ~ loc + s(week, by=loc, k=8),
              na.action = na.exclude,
              family=negbin(link="log", theta= 1.2),              
              data = dframe1)
summary(model1)

# Model validation ####
over.dispersion.statistic <- model1$deviance / model1$df.residual
over.dispersion.statistic

# Checking model assumptions
resid <- residuals(model1)
hist(resid)
fits <- fitted.values(model1)
plot(resid ~ fits, log = "x")
#....####

# Plotting seasonal variation at Hobbit Hole vs. adjacent woodland (FIGURE 3) ####
quartz()

plot(no ~ week, pch=1, col = "red",
     data = dframe1, subset = dframe1$loc=="0", 
     las=1,
     xlim=c(10,50), ylim=c(0,1500),
     xlab = "Week", ylab = "No. of files recorded")
points(no ~ week, pch=1, col = "blue",
       data = dframe1, subset = dframe1$loc=="1")

pdat <- expand.grid(week=seq(12,48,0.1), loc="0")
preds <- predict(model1, newdata=pdat, se.fit=T, type="response")
predframe <- data.frame(pdat, preds)
predframe

lines(fit ~ week, data=predframe, lwd=2, col= "red")
lines(fit + se.fit ~ week, data=predframe, lty=2, col= "red")
lines(fit - se.fit ~ week, data=predframe, lty=2, col= "red")

pdat <- expand.grid(week=seq(12,48,0.1), loc="1")
preds <- predict(model1, newdata=pdat, se.fit=T, type="response")
predframe <- data.frame(pdat, preds)
predframe

lines(fit ~ week, data=predframe, lwd=2, col= "blue")
lines(fit + se.fit ~ week, data=predframe, lty=2, col= "blue")
lines(fit - se.fit ~ week, data=predframe, lty=2, col= "blue")
#....####


#### Plotting seasonal variation at Hobbit Hole vs other caves (FIGURE 4) ####

quartz()

plot(no ~ week, pch=1, col = "red",
     data = dframe1, subset = dframe1$loc=="0",    # location 0 = Hobbit Hole
     las=1, cex = 0.5,
     xlim=c(10,50), ylim=c(0,1500),
     xlab = "Week", ylab = "No. of files recorded")
points(no ~ week, pch=1, col = "blue", cex = 0.5,
       data = dframe1, subset = dframe1$loc=="2")  # location 2 = Middle Earth
points(no ~ week, pch=1, col = "black", cex = 0.5,
       data = dframe1, subset = dframe1$loc=="3")  # location 3 = Damocles


# Prediction for Hobbit Hole
pdat <- expand.grid(week=seq(12,48,0.1), loc="0")
preds <- predict(model1, newdata=pdat, se.fit=T, type="response")
predframe <- data.frame(pdat, preds)
predframe

lines(fit ~ week, data=predframe, lwd=2, col= "red")
lines(fit + se.fit ~ week, data=predframe, lty=2, col= "red")
lines(fit - se.fit ~ week, data=predframe, lty=2, col= "red")

# Prediction for Middle Earth
pdat <- expand.grid(week=seq(12,48,0.1), loc="2")
preds <- predict(model1, newdata=pdat, se.fit=T, type="response")
predframe <- data.frame(pdat, preds)
predframe

lines(fit ~ week, data=predframe, lwd=2, col= "blue")
lines(fit + se.fit ~ week, data=predframe, lty=2, col= "blue")
lines(fit - se.fit ~ week, data=predframe, lty=2, col= "blue")

# Prediction for Damocles
pdat <- expand.grid(week=seq(12,48,0.1), loc="3")
preds <- predict(model1, newdata=pdat, se.fit=T, type="response")
predframe <- data.frame(pdat, preds)
predframe

lines(fit ~ week, data=predframe, lwd=2, col= "black")
lines(fit + se.fit ~ week, data=predframe, lty=2, col= "black")
lines(fit - se.fit ~ week, data=predframe, lty=2, col= "black")
#....####
#....####


#### Model of weather / swarming effects (model reported in TABLE 3) ####

#### Reading in and checking the data ####
dframe1 <- read.csv(file.choose())  # select "Hip Hobbit 2015 & 2016.CSV"
summary(dframe1)

# Change year into a factor with 2 levels (2015 and 2016)
dframe1$year <- as.factor(dframe1$year)
summary(dframe1)

# Change Swarm into a factor with 2 levels (0 = outside swarming season, and 1 = swarming season)
dframe1$Swarm <- as.factor(dframe1$Swarm)
summary(dframe1)
#....####

## The model ####

library(mgcv)
model1 <- gam(no ~ s(week, by = year, k=8) + Swarm
              + s(tfil, by = Swarm, k = 6) + s(rfil, by = Swarm, k = 6)
              ,
              family=negbin(link="log", theta= 1.27),   # overdispersion parameter theta=1.27
              data = dframe1)

# Model validation ####
over.dispersion.statistic <- model1$deviance / model1$df.residual
over.dispersion.statistic

summary(model1)
AIC(model1)

# Checking model assumptions
resid <- residuals(model1)
hist(resid)
fits <- fitted.values(model1)
plot(resid ~ fits, log = "x")
#....####


# Plotting temperature effects ####

quartz()

plot(no ~ tfil, pch=1, col = "red",
     data = dframe1, subset = dframe1$Swarm=="1", 
     las=1,
     xlim=c(0,25), ylim=c(0,2000),
     xlab = "Temperature (degrees C)", ylab = "No. of files recorded")
points(no ~ tfil, pch=1, col = "blue",
       data = dframe1, subset = dframe1$Swarm=="0")


pdat <- expand.grid(tfil=seq(2,16,0.1), Swarm="1", week = 20, year = "2015", rfil=0)
preds <- predict(model1, newdata=pdat, se.fit=T, type="response")
predframe <- data.frame(pdat, preds)
predframe

lines(fit ~ tfil, data=predframe, lwd=2, col= "red")
lines(fit + se.fit ~ tfil, data=predframe, lty=2, col= "red")
lines(fit - se.fit ~ tfil, data=predframe, lty=2, col= "red")


pdat <- expand.grid(tfil=seq(4,20,0.1), Swarm="0", week = 30, year = "2015", rfil=0)
preds <- predict(model1, newdata=pdat, se.fit=T, type="response")
predframe <- data.frame(pdat, preds)
predframe

lines(fit ~ tfil, data=predframe, lwd=2, col= "dark blue")
lines(fit + se.fit ~ tfil, data=predframe, lty=2, col= "dark blue")
lines(fit - se.fit ~ tfil, data=predframe, lty=2, col= "dark blue")


# Plotting rainfall effects ####

quartz()

plot(no ~ rfil, pch=1, col = "red",
     data = dframe1, subset = dframe1$Swarm=="1", 
     las=1,
     xlim=c(0,25), ylim=c(0,2000),
     xlab = "Rainfall (mm)", ylab = "No. of files recorded")
points(no ~ tfil, pch=1, col = "blue",
       data = dframe1, subset = dframe1$Swarm=="0")


pdat <- expand.grid(rfil=seq(0,10,0.1), Swarm="1", week = 20, year = "2015", tfil=10)
preds <- predict(model1, newdata=pdat, se.fit=T, type="response")
predframe <- data.frame(pdat, preds)
predframe

lines(fit ~ rfil, data=predframe, lwd=2, col= "red")
lines(fit + se.fit ~ rfil, data=predframe, lty=2, col= "red")
lines(fit - se.fit ~ rfil, data=predframe, lty=2, col= "red")


pdat <- expand.grid(rfil=seq(4,18,0.1), Swarm="0", week = 20, year = "2015", tfil=10)
preds <- predict(model1, newdata=pdat, se.fit=T, type="response")
predframe <- data.frame(pdat, preds)
predframe

lines(fit ~ rfil, data=predframe, lwd=2, col= "dark blue")
lines(fit + se.fit ~ rfil, data=predframe, lty=2, col= "blue")
lines(fit - se.fit ~ rfil, data=predframe, lty=2, col= "blue")
#....####
#....####



# A GAM model of bat activity over the night ####
# Reading in and checking the data ####

dframe1 <- read.csv(file.choose()) # Select "Hourly Analysis.CSV"
summary(dframe1)

dframe1$Year <- as.factor(dframe1$Year) # Convert Year to a categorical variable
dframe1$Group <- relevel(dframe1$Group, ref = "Pre15")

#....####

# The model ####
library(mgcv)
library(MASS)
model1 <- gam(Files ~ s(Hour, k=7, by = Group) + Group, 
              family = negbin(theta=0.6), data = dframe1)

# Model validation ####
AIC(model1)

# Calculate the overdispersion statistic.
# Overdispersion = residual devaince / residual d.f.
overdispersion <- model1$deviance / model1$df.residual
overdispersion

# Checking model assumptions
resid <- residuals(model1)
hist(resid)
fits <- fitted.values(model1)
plot(resid ~ fits)

summary(model1)
plot(model1)
#....####

# Plotting model predictions ####

# (i) Pre-swarming season ####

# Plot the raw data
par(mar=c(4.2,4,1,1))

plot(Files ~ Hour, data=dframe1, col = "white", las= 1, 
     ylab = "No. of files",  ylim=c(0,400),
     xlab = "Hours relative to midnight (GMT)")
points(Files ~ Hour, data = dframe1, 
       subset=dframe1$Period=="Pre",
       pch = 19, col =rgb(0.5,0.5,0.5,0.2))

# Pre-swarming 2015 ####

# Step 1: Making a table of prediction data (pdat), for example???
pdat <- expand.grid(Group = "Pre15",
                    Hour = seq(-4,5,0.1))
pdat

# Step 2: Making a file containing the predicted data (pred) 
pred <- predict (model1, newdata = pdat, na.rm = T,
                 type= "response", se.fit = TRUE) 
pred

# Step 3: combine the predictions with the predictors, into a final dataframe 
predframe <- data.frame (pdat, preds = pred)
predframe

# Step 4: plot a line for y vs. the smoothed variable, and add the fitted lines +/-SE
lines(preds.fit ~ Hour, data=predframe, lwd = 1.5)
lines(preds.fit+preds.se.fit ~ Hour, data=predframe, lty = 2)
lines(preds.fit-preds.se.fit ~ Hour, data=predframe, lty = 2)


# Pre-swarming 2016 ####

# Step 1: Making a table of prediction data (pdat), for example???
pdat <- expand.grid(Group = "Pre16",
                    Hour = seq(-5,5,0.1)); pdat

# Step 2: Making a file containing the predicted data (pred) 
pred <- predict (model1, newdata = pdat, na.rm = T,
                 type= "response", se.fit = TRUE); pred

# Step 3: combine the predictions with the predictors, into a final dataframe 
predframe <- data.frame (pdat, preds = pred); predframe

# Step 4: plot a line for y vs. the smoothed variable, and add the fitted lines +/-SE
lines(preds.fit ~ Hour, data=predframe, lwd = 1.5)
lines(preds.fit+preds.se.fit ~ Hour, data=predframe, lty = 2)
lines(preds.fit-preds.se.fit ~ Hour, data=predframe, lty = 2)


# (ii) Swarming season ####

# Plot the raw data
plot(Files ~ Hour, data=dframe1, col = "white", las= 1, ylab = "no. of files",  ylim=c(0,400))
points(Files ~ Hour, data = dframe1, 
       subset=dframe1$Period=="Swarm",
       pch = 19, col =rgb(0.5,0.5,0.5,0.2))

# Swarming 2015 ####

# Step 1: Making a table of prediction data (pdat), for example???
pdat <- expand.grid(Group = "Swarm15",
                    Hour = seq(-4,5,0.1))
pdat

# Step 2: Making a file containing the predicted data (pred) 
pred <- predict (model1, newdata = pdat, na.rm = T,
                 type= "response", se.fit = TRUE) 
pred

# Step 3: combine the predictions with the predictors, into a final dataframe 
predframe <- data.frame (pdat, preds = pred)
predframe

# Step 4: plot a line for y vs. the smoothed variable, and add the fitted lines +/-SE
lines(preds.fit ~ Hour, data=predframe, lwd = 1.5)
lines(preds.fit+preds.se.fit ~ Hour, data=predframe, lty = 2)
lines(preds.fit-preds.se.fit ~ Hour, data=predframe, lty = 2)


# Swarming 2016 ####

# Step 1: Making a table of prediction data (pdat), for example???
pdat <- expand.grid(Group = "Swarm16",
                    Hour = seq(-5,6,0.1)); pdat

# Step 2: Making a file containing the predicted data (pred) 
pred <- predict (model1, newdata = pdat, na.rm = T,
                 type= "response", se.fit = TRUE); pred

# Step 3: combine the predictions with the predictors, into a final dataframe 
predframe <- data.frame (pdat, preds = pred); predframe

# Step 4: plot a line for y vs. the smoothed variable, and add the fitted lines +/-SE
lines(preds.fit ~ Hour, data=predframe, lwd = 1.5)
lines(preds.fit+preds.se.fit ~ Hour, data=predframe, lty = 2)
lines(preds.fit-preds.se.fit ~ Hour, data=predframe, lty = 2)


# (iii) Post-Swarming season ####

# Plot the raw data
plot(Files ~ Hour, data=dframe1, col = "white", las= 1, 
     ylab = "no. of files",  ylim=c(0,400),
     xlab = "Hours relative to midnight (GMT)")
points(Files ~ Hour, data = dframe1, 
       subset=dframe1$Period=="Post",
       pch = 19, col =rgb(0.5,0.5,0.5,0.2))

# Post-swarming 2015 ####

# Step 1: Making a table of prediction data (pdat), for example???
pdat <- expand.grid(Group = "Post15",
                    Hour = seq(-3,4,0.1))
pdat

# Step 2: Making a file containing the predicted data (pred) 
pred <- predict (model1, newdata = pdat, na.rm = T,
                 type= "response", se.fit = TRUE) 
pred

# Step 3: combine the predictions with the predictors, into a final dataframe 
predframe <- data.frame (pdat, preds = pred)
predframe

# Step 4: plot a line for y vs. the smoothed variable, and add the fitted lines +/-SE
lines(preds.fit ~ Hour, data=predframe, lwd = 1.5)
lines(preds.fit+preds.se.fit ~ Hour, data=predframe, lty = 2)
lines(preds.fit-preds.se.fit ~ Hour, data=predframe, lty = 2)


# Post-swarming 2016 ####

# Step 1: Making a table of prediction data (pdat), for example???
pdat <- expand.grid(Group = "Post16",
                    Hour = seq(-4,5,0.1)); pdat

# Step 2: Making a file containing the predicted data (pred) 
pred <- predict (model1, newdata = pdat, na.rm = T,
                 type= "response", se.fit = TRUE); pred

# Step 3: combine the predictions with the predictors, into a final dataframe 
predframe <- data.frame (pdat, preds = pred); predframe

# Step 4: plot a line for y vs. the smoothed variable, and add the fitted lines +/-SE
lines(preds.fit ~ Hour, data=predframe, lwd = 1.5)
lines(preds.fit+preds.se.fit ~ Hour, data=predframe, lty = 2)
lines(preds.fit-preds.se.fit ~ Hour, data=predframe, lty = 2)
#....####

#### END ####

